@@ -7,20 +7,16 @@
 package token
 
 import (
-	"github.com/sirupsen/logrus"
 	"github.com/suzuki-shunsuke/pinact/v3/pkg/github"
-	ghTokenCLI "github.com/suzuki-shunsuke/urfave-cli-v3-util/keyring/ghtoken/cli"
+	"github.com/suzuki-shunsuke/slog-util/slogutil"
+	"github.com/suzuki-shunsuke/urfave-cli-v3-util/keyring/ghtoken"
 	"github.com/urfave/cli/v3"
 )
 
 // New creates a new token command for the CLI.
 // It initializes a GitHub token management command using the system keyring
 // for secure credential storage and retrieval.
-//
-// Parameters:
-//   - logE: logrus entry for structured logging
-//
 // Returns a pointer to the configured CLI command for token operations.
-func New(logE *logrus.Entry) *cli.Command {
-	return ghTokenCLI.New(logE, github.KeyService)
+func New(logger *slogutil.Logger) *cli.Command {
+	return ghtoken.Command(ghtoken.NewActor(logger.Logger, github.KeyService))
 }
