@@ -8,10 +8,14 @@ type Secrets struct {
 
 // SetFromEnv sets secrets from environment variables.
 func (s *Secrets) SetFromEnv(getEnv func(string) string) {
-	s.GitHubToken = getEnv("GITHUB_TOKEN")
-	for _, envName := range []string{"GHES_TOKEN", "GITHUB_TOKEN_ENTERPRISE", "GITHUB_ENTERPRISE_TOKEN"} {
+	s.GitHubToken = getEnv("PINACT_GITHUB_TOKEN")
+	if s.GitHubToken == "" {
+		s.GitHubToken = getEnv("GITHUB_TOKEN")
+	}
+	for _, envName := range []string{"PINACT_GHES_TOKEN", "GHES_TOKEN", "GITHUB_TOKEN_ENTERPRISE", "GITHUB_ENTERPRISE_TOKEN"} {
 		if token := getEnv(envName); token != "" {
 			s.GHESToken = token
+			return
 		}
 	}
 }
@@ -26,4 +30,5 @@ func SetEnv(flags *Flags, getEnv func(string) string) {
 	flags.IsGitHubActions = getEnv("GITHUB_ACTIONS") == trueS
 	flags.FallbackEnabled = getEnv("PINACT_GHES_FALLBACK") == trueS
 	flags.KeyringEnabled = getEnv("PINACT_KEYRING_ENABLED") == trueS
+	flags.GHTKNEnabled = getEnv("PINACT_GHTKN") == trueS
 }
